@@ -28,7 +28,7 @@ my $MAP_DESCR_FILE = "../nfdump/bin/nfx.c";
 my $MASTER_RECORD_FILE = "../nfdump/bin/nffile.h";
 
 # path to libnf C and H source files
-my $LIBNF_C_FILE = "libnf_perl.c";
+my $LIBNF_C_FILE = "libnf.c";
 
 
 # The perl structure parsed from 
@@ -186,7 +186,6 @@ foreach (@MAP_DESCR) {
 	# skip "Required extension" and extension with no description 
 	next if ($_->{'description'} =~ /^Required extension:/);
 	next if ($_->{'description'} =~ /^$/);
-	next if ($_->{'description'} =~ /Compat NEL/);
 
 	my $read = str_count($LIBNF_C_FUNC{'libnf_master_record_to_SV'}, $_->{'id'}); 
 	my $write = str_count($LIBNF_C_FUNC{'libnf_write_row'}, $_->{'id'}); 
@@ -212,7 +211,6 @@ foreach (@MASTER_RECORD) {
 	next if ($_->{'name'} =~ /type|size/); 
 	next if ($_->{'name'} =~ /u\d{2}_\d/);
 	next if ($_->{'name'} =~ /exporter_sysid/); 
-	next if ($_->{'name'} =~ /nat_flags/); 
 
 	my $read = str_count($LIBNF_C_FUNC{'libnf_master_record_to_SV'}, $_->{'name'}); 
 	my $write = str_count($LIBNF_C_FUNC{'libnf_write_row'}, $_->{'name'}); 
